@@ -1,6 +1,6 @@
 import typer
 import gsc
-from gsc import auth, client, verifier, setup_exercise
+from gsc import auth, client, verifier, setup_exercise, reset_exercise
 
 app = typer.Typer()
 
@@ -31,7 +31,6 @@ def login(email: str = typer.Option(..., prompt=True)):
     try:
         auth.login(email)
         success("Login Success.")
-
     except auth.AuthenticationError as e:
         error(str(e))
 
@@ -48,7 +47,7 @@ def ping():
 
 
 @app.command()
-def setup(exercise: str = typer.Argument(...)):
+def setup(exercise: str = typer.Argument(None)):
     try:
         setup_exercise.setup(exercise)
         success("Done.")
@@ -56,6 +55,17 @@ def setup(exercise: str = typer.Argument(...)):
         error(str(e))
 
 
+@app.command()
+def reset():
+    try:
+        reset_exercise.reset()
+        success("Exercise reset.")
+    except setup_exercise.SetupError as e:
+        error(str(e))
+    except reset_exercise.ResetError as e:
+        error(str(e))
+
+
 @app.command()
 def verify(exercise: str = typer.Argument(None)):
     try:
