@@ -2,7 +2,7 @@ import os
 import pathlib
 from gsc import cli
 import gsc.exercises.push_and_pull, gsc.exercises.sync_error, gsc.exercises.merge_conflict
-import gsc.exercises.multiple_remotes
+import gsc.exercises.multiple_remotes, gsc.exercises.use_the_force
 
 
 class SetupError(Exception):
@@ -36,5 +36,7 @@ def setup(gsc_id: str):
         gsc.exercises.merge_conflict.setup()
     elif gsc_id == "multiple_remotes":
         gsc.exercises.multiple_remotes.setup()
+    elif gsc_id == "use_the_force":
+        gsc.exercises.use_the_force.setup()
     else:
         raise SetupError("Unknown Git Scientist exercise. Try upgrading gsc.")
